# CHANGELOG

<!-- version list -->

## v1.11.3 (2026-02-10)

### Bug Fixes

- Add missing element-config.json
  ([`37c8b76`](https://github.com/jupyter-naas/abi/commit/37c8b76da2d9124e48b5f2548dd7d2bf296af959))


## v1.11.2 (2026-02-10)


## v1.11.1 (2026-02-10)

### Bug Fixes

- Add template .env
  ([`194421b`](https://github.com/jupyter-naas/abi/commit/194421b7828713606e30144f77a2fcd6c3c32b81))

- Add template .env
  ([`b5fbe73`](https://github.com/jupyter-naas/abi/commit/b5fbe731c7bd37bb12348fc0ddbe75b5c5a8aa78))

- Add template .env
  ([`8c9d43d`](https://github.com/jupyter-naas/abi/commit/8c9d43dda47f569b342d44f7d4789b853d6e72d1))


## v1.11.0 (2026-02-09)

### Bug Fixes

- Working on make check
  ([`32b09fa`](https://github.com/jupyter-naas/abi/commit/32b09fa17ff2eecd17208f5b2800f418062676af))

- Working on make check
  ([`64dc00f`](https://github.com/jupyter-naas/abi/commit/64dc00fd8ce415de7d4d977a8d83d834a67a5aa6))

- Working on make check
  ([`2b9972d`](https://github.com/jupyter-naas/abi/commit/2b9972d9602036e6a926ed0a7b469e1dc1b9bb2f))

- Working on make check
  ([`da6c160`](https://github.com/jupyter-naas/abi/commit/da6c160ab55d1ec4c56cdbe3dc3ddef67144d043))

### Features

- Working on deploy local cli
  ([`c3ffe6d`](https://github.com/jupyter-naas/abi/commit/c3ffe6db633f2ce7789de5460d8849f80490b699))

- Working on deploy local cli
  ([`798e02a`](https://github.com/jupyter-naas/abi/commit/798e02ad2576f86344a54068fcd00e8f717c977d))


## v1.10.2 (2026-02-09)

### Bug Fixes

- Agent templating
  ([`e199010`](https://github.com/jupyter-naas/abi/commit/e199010ceea5d4024e6c24337a36a2413eed8659))


## v1.10.1 (2026-02-09)

### Bug Fixes

- Update CLI and rename KVService
  ([`00e62d6`](https://github.com/jupyter-naas/abi/commit/00e62d61c51e36f792cbdc2540e527596df67097))


## v1.10.0 (2026-02-03)

### Features

- Working on Dagster orchestration
  ([`b970d21`](https://github.com/jupyter-naas/abi/commit/b970d21e135ab32c344122be50f292c0b44ff039))


## v1.9.1 (2026-01-26)

### Bug Fixes

- CICD checks
  ([`1cc9a0d`](https://github.com/jupyter-naas/abi/commit/1cc9a0d8aa9e5b89c06269f11b8437d3a60d2c23))


## v1.9.0 (2026-01-25)


## v1.8.1 (2026-01-25)


## v1.8.0 (2026-01-25)


## v1.7.0 (2026-01-25)


## v1.6.1 (2026-01-24)


## v1.6.0 (2026-01-24)


## v1.5.0 (2026-01-24)

### Bug Fixes

- Naas-abi-cli release
  ([`25e669f`](https://github.com/jupyter-naas/abi/commit/25e669f95dc64f689f1d134d89845bad055333b6))

### Features

- Working on improving project initialization
  ([`e7063bb`](https://github.com/jupyter-naas/abi/commit/e7063bb63a7d3b553f159861fb3e1c545e7d8849))


## v1.4.4 (2026-01-15)


## v1.4.3 (2026-01-15)

### Bug Fixes

- Handle payment required for space creation
  ([`265fa48`](https://github.com/jupyter-naas/abi/commit/265fa48e71976465843f4a0676fe7571f06dab8f))


## v1.4.2 (2026-01-08)

### Bug Fixes

- Tipo license
  ([`f639213`](https://github.com/jupyter-naas/abi/commit/f639213b6c680d211c9618737842f01b51a65f8d))

- Tipo license
  ([`0269100`](https://github.com/jupyter-naas/abi/commit/0269100ca7d2d338d1f68be0717be6e981cc8eac))


## v1.4.1 (2026-01-08)

### Bug Fixes

- Add project urls in pyproject.toml
  ([`c155efa`](https://github.com/jupyter-naas/abi/commit/c155efa2a794b44312eb90ae19ab1c0da402d3ef))


## v1.4.0 (2026-01-08)


## v1.3.0 (2026-01-08)

### Features

- Add README.md to cli
  ([`00c4b50`](https://github.com/jupyter-naas/abi/commit/00c4b50f7eeef7170a52fa9a91c025befde13299))


## v1.2.0 (2026-01-07)


## v1.1.0 (2026-01-07)


## v1.0.3 (2026-01-07)

### Bug Fixes

- Add Dockerfile to new project generation
  ([`3cc8ecd`](https://github.com/jupyter-naas/abi/commit/3cc8ecddd80e247b10c7273862f5cfffb33969c5))

- Update config.yaml template on new project generation
  ([`72a174e`](https://github.com/jupyter-naas/abi/commit/72a174efdc779374f4035b3c91ba2aaf035ff6ce))


## v1.0.2 (2025-12-19)


## v1.0.1 (2025-12-19)

### Bug Fixes

- Add missing config in template
  ([`d4df148`](https://github.com/jupyter-naas/abi/commit/d4df148450f356a94ab53b46580db20bbba325b1))


## v1.0.0 (2025-12-19)

- Initial Release
